# -*- coding: utf-8 -*-

"""Board game recommenders."""

from .__version__ import VERSION, __version__
from .recommend import BGARecommender, BGGRecommender, GamesRecommender
